@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Classes.tcl,v $
-# $Date: 1998/09/02 12:02:04 $
-# $Revision: 1.18.1.90 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Classes.tcl,v $
+# $Date: 1998/10/28 17:27:02 $
+# $Revision: 1.18.1.92 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -135,6 +135,7 @@ class DChat {
 class Server {
     host	{}	{host}
     port	6667	{port}
+    ip		{}	{ipaddr}
     oper	{}	{id}
     operpw	{}	{pass}
     script	{}	{script}
