@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Monitor.tcl,v $
-# $Date: 1998/04/27 11:46:02 $
-# $Revision: 1.18.1.16 $
+# $Date: 1998/05/28 09:33:18 $
+# $Revision: 1.18.1.18 $
 #
 package provide zircon 1.18
 #
@@ -20,20 +20,16 @@ proc monitor_remove {this usr} {
 }
 #
 proc monitor_update {this names} {
-    set w [$this window]
+    if {![winfo exists [set w [$this window]]]} return
     set xist {}
     foreach n [winfo children $w.usr] { lappend xist [winfo name $n] }
     set net [$this net]
     foreach n $names {
 	switch {} $n continue
 	regexp {^([@+]?)(.*)} $n m mrk n
-	switch $mrk {
-	@ { set mrk operator} 
-	+ { set mrk speaker}
-	}
 	set usr [User :: make $net $n]
 	if {![winfo exists [set winu $w.usr.$usr]]} {
-	    wsortIns nil $w.usr $n $usr
+	    wsortIns nil $w.usr $n $usr $mrk
 	    $usr ref
 	} {
 	    if {![normal $winu]} {
@@ -42,6 +38,10 @@ proc monitor_update {this names} {
 	    }
 	    listkill xist $usr
 	}
+	switch $mrk {
+	@ { set mrk operator} 
+	+ { set mrk speaker}
+	}
 	markButton $net $winu $mrk
     }
     foreach n $xist {if {[normal $w.usr.$n]} {destroy $w.usr.$n ; $n deref}}
