@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/09/23 11:29:56 $
-# $Revision: 1.18.1.154 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Net.tcl,v $
+# $Date: 1998/10/28 10:20:16 $
+# $Revision: 1.18.1.156 $
 #
 package provide zircon 1.18
 #
@@ -277,7 +277,7 @@ proc net_show {this} {
 #
 proc net_startIRC {this srv args} {
     switch nil $srv {return 0}
-    global connected
+    global connected zircon
     upvar #0 $this ndata
     $this show
     set server [$srv host]
@@ -299,13 +299,17 @@ proc net_startIRC {this srv args} {
 	    update idletasks
 	    $this slow
 	    set ndata(sock) {}
-	    set scmd socket
-	    foreach x {myaddr myport } {
-		switch {} $ndata($x) {} default {
-		    append scmd " -$x $ndata($x)"
+	    if {[info exists zircon(sockshost)]} {
+		set scmd SOCKSet
+	    } {
+		set scmd socket
+		foreach x {myaddr myport } {
+		    switch {} $ndata($x) {} default {
+			append scmd " -$x $ndata($x)"
+		    }
 		}
+		append scmd " -async $server $port"
 	    }
-	    append scmd " -async $server $port"
 	    if {[catch {eval $scmd} sock]} {
 		$this errmsg "Cannot connect to port $port of server $server ($sock)"
 		set ndata(sock) {}
@@ -654,7 +658,7 @@ proc net_isonTest {this} {
     upvar #0 $this ndata
     $this ISON
     foreach gf  [$this globfriend] {
-        $this sysQ "WHO :$gf"
+	$this sysQ "WHO :$gf"
 	lappend ndata(whohandler) globfon
     }
     if {$ndata(notifyInterval)} {after $ndata(notifyInterval) "$this isonTest"}
@@ -840,7 +844,7 @@ proc net_delete {this} {
     catch {deleteFrame .@dbgctl $this}
     $this removeAfters
     safeUnset [list XTO([string tolower [$this name]])] OType($this) \
-      $this Split$net Heal$net TSplit$net
+      $this Split$this Heal$this TSplit$this
     global znetList
     listkill znetList $this
     remShareLook $this
@@ -848,7 +852,7 @@ proc net_delete {this} {
 }
 #
 proc net_removeAfters {this} {
-    upvar #0 TSplit$net TSplit Heal$net Heal
+    upvar #0 TSplit$this TSplit Heal$this Heal
     foreach {x y} [array get TSplit] { after cancel $y }
     foreach {x y} [array get Heal] { after cancel $y }
 }
