@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Server.tcl,v $
-# $Date: 1998/06/26 08:48:01 $
-# $Revision: 1.18.1.29 $
+# $Date: 1998/07/10 13:33:52 $
+# $Revision: 1.18.1.30 $
 #
 #
 package provide zircon 1.18
@@ -39,7 +39,7 @@ proc server_configure {this args} {
 	switch -exact -- $opt {
 	+port {
 	    if {![listmember $sdata(port) $val]} {
-	        lappend sdata(list) $port
+	        lappend sdata(list) $val
 		set sdata(port) [lsort -integer $sdata(port)]
 	    }
 	    set sdata(selport) $val
