@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Tracing.tcl,v $
-# $Date: 1998/09/02 12:57:35 $
-# $Revision: 1.18.1.32 $
+# $Date: 1998/10/28 10:23:14 $
+# $Revision: 1.18.1.34 $
 #
 #
 package provide Tracing 1.18
@@ -101,11 +101,55 @@ proc net_q1Send {this op} {
     if {[catch {puts $ndata(sock) $op} err]} { $this close $err ; return 1}
     return 0
 }
+
+#
+proc SOCKSet {host port} {
+    global zircon
+    if {[set match [scan $host "%d.%d.%d.%d" a b c d]] != 4} {
+        error "SOCKS ERROR: Host must be IP address, not name"
+    }
+    zOut "**** Connecting to socks host" $currentNet
+
+    if {[catch {socket $zircon(sockshost) $zircon(socksport)} sk]} {
+        zOut "**** Error Connecting to socks host : $sk" $currentNet
+	error $sk
+    }
+    puts -nonewline $sk [binary format "ccScccca*c" 4 1 $port $a $b $c $d $sname 0]
+    flush $sk
+
+
+    fileevent $sk readable "SOCKSreply $sk"
+    set SOCKSwait($sk) 0
+    vwait SOCKSwait($sk)
+    if {[set r $SOCKSwait($sk)] != "90"} {
+        unset SOCKSwait($sk)
+	error "SOCKS Request failed code : $r"
+    }
+    unset SOCKSwait($sk)
+    zOut "**** Connected to $host:$port" $currentNet
+    return $sk
+}
+#
+proc SOCKSreply {sk} {
+    global currentNet SOCKSwait
+    binary scan [read $sk 8] "ccSI" v r port ip
+    
+    if {[set SOCKSwait($sk) $r] != "90" } {
+        zOut "**** SOCKS error $r" $currentNet
+    } {
+        zOut "**** Connected" $currentNet
+    }
+}
 #
 proc connect {host port} {
-    global currentNet
+    global currentNet zircon
+    if {[info exists zircon(sockshost)]} {
+        set scm SOCKSet
+    } {
+        set scm socket
+    }
     zOut "**** Connecting to $host:$port" $currentNet
-    if {[catch {socket $host $port} sk]} {
+    if {[catch {$scm $host $port} sk]} {
 	zOut "**** Connect error - $sk" $currentNet
 	error $sk
     }
