@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Util.tcl,v $
-# $Date: 1998/09/24 08:16:58 $
-# $Revision: 1.18.1.78 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Util.tcl,v $
+# $Date: 1998/10/08 09:37:57 $
+# $Revision: 1.18.1.79 $
 #
 package provide zircon 1.18
 #
@@ -646,7 +646,7 @@ proc fullName {file} {
     return $file
 }
 #
-proc safeUnset {args} { foreach x $args { catch {uplevel #0 unset $x} msg } }
+proc safeUnset {args} { foreach x $args { catch {uplevel #0 unset $x} }}
 #
 proc safeDestroy {args} { foreach x $args { catch {destroy $x} } }
 #
