@@ -1,7 +1,7 @@
 
 # $Source: /home/nlfm/Zircon/lib/RCS/ctcp.tcl,v $
-# $Date: 1998/08/19 12:17:38 $
-# $Revision: 1.18.1.36 $
+# $Date: 1998/10/28 10:20:20 $
+# $Revision: 1.18.1.37 $
 #
 package provide zircon 1.18
 #
@@ -15,7 +15,7 @@ proc ctcpReply {net chan nk op str} {
 proc handleCTCP {net op chid chan usr prefix ign param} {
     if {[ignoreSet $ign ctcp]} { return {}}
     if {![regexp [$net ctcpPattern] $chan]} { return {} }
-    handleOn $net CTCP [list $op $prefix $param]
+    handleOn $net CTCP [list $op $prefix $param [$chan name]]
     global zircon
     set nk [$usr name]
     switch -glob -- $op {
