@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/catless/Working/Zircon/Released/lib/RCS/tcl75.tcl,v $
-# $Date: 1998/07/24 15:10:29 $
-# $Revision: 1.18.1.19 $
+# $Source: /home/nlfm/Zircon/lib/RCS/tcl75.tcl,v $
+# $Date: 1998/10/16 10:17:41 $
+# $Revision: 1.18.1.20 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -11,6 +11,11 @@
 #
 package provide interp 7.5
 #
+proc usesocks {args} {
+    puts stderr "Sorry, but to use SOCKS you must upgrade to tcl/tk 8.0"
+    exit 1
+}
+#
 #
 proc sconf {sk enc} {
     global hostIPaddress
