@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/tcl76.tcl,v $
-# $Date: 1998/09/04 14:48:39 $
-# $Revision: 1.18.1.20 $
+# $Date: 1998/10/16 10:17:42 $
+# $Revision: 1.18.1.21 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -12,6 +12,11 @@
 #
 package provide interp 7.6
 #
+proc usesocks {args} {
+    puts stderr "Sorry, but to use SOCKS you must upgrade to tcl/tk 8.0"
+    exit 1
+}
+#
 proc sconf {sk enc} {
     global hostIPaddress
     fconfigure $sk -buffering line -translation {auto lf} -blocking 0
