@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/tcl80.tcl,v $
-# $Date: 1998/09/04 14:48:39 $
-# $Revision: 1.18.1.6 $
+# $Source: /home/nlfm/catless/Zircon/lib/RCS/tcl80.tcl,v $
+# $Date: 1998/10/16 10:17:43 $
+# $Revision: 1.18.1.7 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -12,6 +12,14 @@
 #
 package provide interp 8.0
 #
+proc usesocks {host args} {
+    global zircon
+    set zircon(sockshost) $host
+    switch {} $args { set zircon(socksport) [lindex $args 0]} default {
+	set zircon(socksport) 1080
+    }
+}
+#
 proc sconf {sk enc} {
     global hostIPaddress
     fconfigure $sk -buffering line -translation {auto lf} -blocking 0
